@@ -155,7 +155,7 @@ class baseWebBrowserController:
         """
         
         # URLログ出力
-        Logger.logging.info('TargetUrl]' + url)
+        Logger.logging.info('[TargetUrl]=' + url)
 
         # ページ内容取得
         if self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.selenium.value:
@@ -203,13 +203,25 @@ class baseWebBrowserController:
         # タイムアウト設定
         self.wDriver.implicitly_wait(self.config.WebDriverTimeout)
         # 検索結果エレメント取得
-        if locater == By.CSS_SELECTOR:
-            element = self.wDriver.find_element_by_css_selector(self.config.DelayWaitElement)
-        elif locater == By.CLASS_NAME:
-            element = self.wDriver.find_element_by_class_name(self.config.DelayWaitElement)
-        elif locater == By.TAG_NAME:
-            element = self.wDriver.find_element_by_tag_name(self.config.DelayWaitElement)
-
+        error_count = 0
+        while True:
+            try:
+                
+                if locater == By.CSS_SELECTOR:
+                    element = self.wDriver.find_element_by_css_selector(self.config.DelayWaitElement)
+                elif locater == By.CLASS_NAME:
+                    element = self.wDriver.find_element_by_class_name(self.config.DelayWaitElement)
+                elif locater == By.TAG_NAME:
+                    element = self.wDriver.find_element_by_tag_name(self.config.DelayWaitElement)
+                break
+            except Exception as e:
+                error_count += 1
+                
+                if error_count >= self.config.PageLoadRetryCount:
+                    Logger.logging.error('Load Page Timeout Exception. ErrorDescription={}'.format(str(e)))
+                    break
+                else:
+                    time.sleep(0.1)
         return element
 
     @Logger.loggerDecorator('WebDriver-SetOption')
@@ -248,8 +260,8 @@ class baseWebBrowserController:
 
             # データ作成後処理
             retDataFrame = self.createSearchResultDataFrameAfterProc(retDataFrame, *args, **kwargs)
-        except:
-            raise Exception
+        except Exception as e:
+            raise e
             
         # 戻り値を返す
         return retDataFrame
